# SmileRating
This a custom Widget for Qt Designer provides a graphical interface to collect the degree of satisfaction of a product or service in an intuitive and pleasant way, to later collect results and assess the opinions of consumers of the product or service.